#include <sys/klog.h>
#include <sys/mount.h>
#include <sys/reboot.h>
#include <signal.h>
#include <stdio.h>
#include <unistd.h>

#include "ansi.h"
#include "caronte.h"
#include "hardware.h"
#include "makedir.h"

static int shutdown = 0;

static void caronte_reboot() {
  // Reboot
  printf("Syncing disks ...\n");
  sync();
  printf("Umounting /proc ...\n");
  umount("/proc");
  printf("Rebooting in 10 seconds ...\n");
  shutdown=1;
//  sleep(10);
  sync();
//  reboot(RB_AUTOBOOT);
}

static void caronte_signal(int sig) {
  color(CURSOR_ON);
  if (sig>0) {
    printf("caronte: got signal %i\n", sig);
    if (shutdown==1) return;
  } else {
    printf("caronte: completed.\n");
  }
  if (shutdown==0) {
    caronte_reboot();
    printf("I'm still alive !\n");
    exit(sig);
  }
  printf("... returning\n");
  return;
}

int main(int argc, char **argv ) {
  int iret;
  TChain     *lista_distribuzioni;	// Elenco dei device contenenti una distribuzione
  TComputer  *tuxbox;

  printf("[ Caronte ]===================================================");
  
  // Setup a signals
  signal( SIGHUP, caronte_signal );
  signal( SIGBUS, caronte_signal );
  signal( SIGINT, caronte_signal );
  signal( SIGTERM, caronte_signal );
  signal( SIGSEGV, caronte_signal );
  signal( SIGPIPE, caronte_signal );

  // lower kernel verbosity level
  printf("Lowering kernel verbosity level");
  klogctl( 8, NULL, 4);
  printf("done\n");
  sleep(1);

  // lower kernel verbosity level
  printf("Disabling CTRL+ALT+DEL");
  reboot(RB_DISABLE_CAD);
  sleep(1);

  // Mounting Proc
  printf("Mounting proc ... ");
  makedir("/proc", 00755 );
  if ( mount( "/proc", "/proc", "proc", 0, NULL ) ) {
    printf("errore\n");
    //caronte_signal(1);
  }
  printf("done\n");
  sleep(1);
  
  // Setting HostName
  printf("Setting hostname ...");
  sethostname("localhost.localdomain",21);
  setdomainname("",0);
  printf("done\n");
  sleep(1);
 
  // Show a gracefull intro
  logo_caronte();

  // Allocate computer and query devices
  tuxbox = create_computer();
  
  // Probe all the partitions
  iret = probe_partitions(tuxbox);

  // Search for all distributions
  lista_distribuzioni = probe_distributions(tuxbox);

  // Monta la partizione
  iret = mount_distribution(lista_distribuzioni);
  
  // Quit
  caronte_signal(0);
  return 0;
}
