
/* Descriptor for a single file hole.  */

struct sparse
{				/* byte offset */
  char offset[12];		/*   0 */
  char numbytes[12];		/*  12 */
				/*  24 */
};

 Sparse files are not supported in POSIX ustar format.  For sparse files
   with a POSIX header, a GNU extra header is provided which holds overall
   sparse information and a few sparse descriptors.  When an old GNU header
   replaces both the POSIX header and the GNU extra header, it holds some
   sparse descriptors too.  Whether POSIX or not, if more sparse descriptors
   are still needed, they are put into as many successive sparse headers as
   necessary.  The following constants tell how many sparse descriptors fit
   in each kind of header able to hold them.  */

#define SPARSES_IN_EXTRA_HEADER  16
#define SPARSES_IN_OLDGNU_HEADER 4
#define SPARSES_IN_SPARSE_HEADER 21

 The GNU extra header contains some information GNU tar needs, but not
   foreseen in POSIX header format.  It is only used after a POSIX header
   (and never with old GNU headers), and immediately follows this POSIX
   header, when typeflag is a letter rather than a digit, so signaling a GNU
   extension.  */

struct extra_header
{				/* byte offset */
  char atime[12];		/*   0 */
  char ctime[12];		/*  12 */
  char offset[12];		/*  24 */
  char realsize[12];		/*  36 */
  char longnames[4];		/*  48 */
  char unused_pad1[68];		/*  52 */
  struct sparse sp[SPARSES_IN_EXTRA_HEADER];
				/* 120 */
  char isextended;		/* 504 */
				/* 505 */
};

 Extension header for sparse files, used immediately after the GNU extra
   header, and used only if all sparse information cannot fit into that
   extra header.  There might even be many such extension headers, one after
   the other, until all sparse information has been recorded.  */

struct sparse_header
{				/* byte offset */
  struct sparse sp[SPARSES_IN_SPARSE_HEADER];
				/*   0 */
  char isextended;		/* 504 */
				/* 505 */
};

#define GNUTYPE_LONGLINK 'K'
#define GNUTYPE_LONGNAME 'L'
#define GNUTYPE_MULTIVOL 'M'
#define GNUTYPE_NAMES 'N'
#define GNUTYPE_SPARSE 'S'
#define GNUTYPE_VOLHDR 'V'

