#ifndef _HARDWARE_H
#define _HARDWARE_H

#include "chain.h"

// ----------------------------------------------[ Config ]----------
#define DIR_PROC_IDE		"/proc/ide/"
#define DIR_PROC_SCSI		"/proc/scsi/"
#define FILE_PROC_SCSI		"/proc/scsi/scsi"
//#define FILE_PROC_SCSI	"data/proc-scsi.txt"

#define TEMPFILE_PARTITIONS 	"/tmp/partitions.tmp"

// -------------------------------------------[ Constants ]----------

// Model description
#define MODEL_UNKNOWN		"Device sconosciuto"

/* 
 * Media Types
 * Kernel enums for EIDE: disk, cdrom, tape, floppy, UNKNOWN
 * Kernel enums for SCSI: Direct-Access, Sequential-Access, Printer, 
 *                        Processor, WORM. CD-ROM, Scanner, Optical Device
 *                        Medium Changer, Communications, Unknown, Enclosure
 */
#define MEDIA_UNKNOWN		"unknown"
#define MEDIA_DISK_EIDE		"disk"
#define MEDIA_CDROM_EIDE	"cdrom"
#define MEDIA_DISK_SCSI		"Direct-Access"


// Filesytems
#define FILESYSTEM_ISO9660	"iso9660"
#define FILESYSTEM_EXT2		"ext2"
#define FILESYSTEM_SWAP		"swap"
#define FILESYSTEM_VFAT		"vfat"
#define FILESYSTEM_NONE		"none"


// -------------------------------------------[ Structure ]----------


// Typedefs
typedef struct stBlockDevice TBlockDevice;
typedef struct stPartition   TPartition;


// Macro for casting
#define TBLOCKDEVICE(X) ((TBlockDevice*)(X))
#define TPARTITION(X)   ((TPartition*)(X))


// Eide cdrom,disks
struct stBlockDevice {
  char *device;
  char *media;
  char *model;
  TChain *partitions;
};

// Partitions attached to a device
struct stPartition {
  char *device;
  char *filesystem;
  long  size;
};

struct stComputer {
  // Classes
  TChain *eide;
  TChain *scsi;
  // Collections
  TChain *partitions;
};


// -------------------------------------------[ Functions ]----------




// Query
int query_eide_devices(TComputer *pc);	
    // Recreate the list of EIDE devices
int query_scsi_devices(TComputer *pc);	
    // Recreate the list of SCSI devices
int query_partitions_device(TBlockDevice *blockdevice);	
    // Recreate the list of partitions attached to a devices
    // without updating the computer->partition collection
int query_partitions(TComputer *computer);	
    // Recreate the list of partitions of each EIDE and SCSI device

#endif
