
  // Controllo Installazione pacchetto
  switch (lostOptions.action) {
    case ACTION_UPDATE:
    case ACTION_RESTORE:
    case ACTION_DELETE:
    case ACTION_PURGE:
    case ACTION_CHECK: {
      if ( 0 != file_exists(lostOptions.spooldir) ) {
        printERROR("Il pacchetto %s non e' installato in %s\n", lostOptions.fullname, lostOptions.targetdir );
	normal_color();
        uscita(ERROR_NONINSTALLATO,&lostOptions);
      }
      break;
    }    
  }	

  // Clean Up FS
  chdir( lostOptions.targetdir );  
  deltree( "install" );
  deltree( "incoming" );
  makedir( lostOptions.spoolroot, 00711 );


// Controlla i dati nella struttura delle opzioni a seconda dell'azione
int check_options( TSetupOptions *lpopt ) {
  switch( lpopt->action ) {
  
    // Almeno 1 action deve essre stata scelta !
    case ACTION_UNKNOWN: {
      printERROR( "! Non e' stata specificata l'azione da eseguire.\n");
      normal_color();
      exit ( ERROR_PARAMETRO );
    }  

#ifdef TODO
    case ACTION_INSTALL:
    case ACTION_UPDATE:
    case ACTION_RESTORE: {
      // Il pacchetto deve essere specificato
      if ( lpopt->sourcefile == NULL ) {
        printERROR( "! Non e' stata specificato il nome del pacchetto.\n");
	normal_color();
        exit ( ERROR_PARAMETRO );
      }  
      // If package does not exist try appending a name to it
      if ( 0 != file_exists(lpopt->sourcefile) ) {
        if ( 0 == check_package_extension( &(lpopt->sourcefile), ".bpp") ) {
          if (lpopt->verbose > 1) {
	    printWARNING( "- Utilizzo %s come nome pacchetto.\n", lpopt->sourcefile );
	    normal_color();
	  }
	} else {
	  printERROR( "! Pacchetto non trovato %s\n", lpopt->sourcefile );
	  normal_color();
	  exit( ERROR_NOTFOUND );
	}
      }
      // La directory deve essere specificata               
      if ( lpopt->targetdir == NULL ) {
        printWARNING( "! Non e' stata specificata la directory di destinazione, presumo /.\n");
	normal_color();
        lpopt->targetdir = strdup("/");
	lpopt->interactive = 1;
      }  
      // La directory deve esistere
      if ( 0 != file_exists(lpopt->targetdir) ) {
        printERROR( "! Directory d'installazione %s inesistente.\n", lpopt->targetdir );
	normal_color();
        exit( ERROR_NOTFOUND );
      }
      break;
    }

    case ACTION_FINALIZE: {
      // Directory di default
      if ( lpopt->sourcefile == NULL ) {
	printWARNING( "! Non e' stata specificata la directory della distribuzione, presumo /cdrom\n");
	normal_color();
        lpopt->sourcefile = strdup("/cdrom");
	lpopt->targetdir = strdup("/");
      }
      if ( lpopt->sourcedir == NULL ) {
        lpopt->sourcedir = strdup( lpopt->sourcefile );
      }
      // La directory (come filename) deve esistere
      if ( 0 != file_exists(lpopt->sourcefile) ) {
        printERROR( "! Directory d'installazione %s inesistente.\n", lpopt->sourcefile );
	normal_color();
        exit( ERROR_NOTFOUND );
      }
      // Directory di default
      if ( lpopt->targetdir == NULL ) {
        printWARNING( "! Non e' stata specificata la directory di destinazione, presumo /.\n");
	normal_color();
        lpopt->targetdir = strdup("/");
      }  
      // La directory deve esistere
      if ( 0 != file_exists(lpopt->targetdir) ) {
        printERROR( "! Directory d'installazione %s inesistente.\n", lpopt->targetdir );
	normal_color();
        exit( ERROR_NOTFOUND );
      }
      break;
    }  

    case ACTION_POSTINSTALL: 
    case ACTION_XPOSTINSTALL: {
      // Ignora parametro nomefile
      if ( lpopt->sourcefile != NULL ) {
        printWARNING( "! Il parametro %s e' stato ignorato.\n", lpopt->sourcefile );
        normal_color();
      }  
      // Ignora parametro directory
      if ( lpopt->targetdir != NULL ) {
        printWARNING( "! Il parametro %s e' stato ignorato.\n", lpopt->targetdir );
	normal_color();
      }
      // queste action possono essere SOLO locali
      lpopt->sourcefile = strdup("/");
      lpopt->targetdir  = strdup("/");
      lpopt->sourcedir  = strdup("/");
      break;
    }

    case ACTION_PURGE: 
    case ACTION_DELETE: 
    case ACTION_CHECK: {
      // Il pacchetto deve essere specificato
      if ( lpopt->sourcefile == NULL ) {
        printERROR( "! Non e' stato specificato il nome del pacchetto.\n");
	normal_color();
        exit ( ERROR_PARAMETRO );
      }  
      // La directory deve essere specificata               
      if ( lpopt->targetdir == NULL ) {
        printWARNING( "! Non e' stata specificata la directory di destinazione, presumo /.\n");
	normal_color();
        lpopt->targetdir = strdup("/");
      }  
      // La directory deve esistere
      if ( 0 != file_exists(lpopt->targetdir) ) {
        printERROR( "! Directory d'installazione %s inesistente.\n", lpopt->targetdir );
	normal_color();
        exit( ERROR_NOTFOUND );
      }
      break;
    }
#endif
    // Il metodo scelto non e' ancora gestito
    default: {
      printERROR( "! Il metodo d'installazione (%i) non e' ancora gestito.\n", lpopt->action );
      normal_color();
      exit( ERROR_PARAMETRO );  
    }
  // End of switch  
  }
  // ok
  return 0;
}

// Calcola alcuni valori non specificati
int adjust_options( TSetupOptions *lpopt ) {
  int i;
  char *s;
  
  // Calcolo della Sourcedir
  if ( lpopt->sourcedir == NULL ) {
    lpopt->sourcedir = dirpath( lpopt->sourcefile );
    if ( 0 == strcmp( ".", lpopt->sourcedir ) ) {
      lpopt->sourcedir = concatenate( getcwd( NULL, 0 ), "/" );
      lpopt->sourcefile = concatenate( lpopt->sourcedir, lpopt->sourcefile );
    }
  }

  // Calcolo nome completo del pacchetto ('dirbase $i .bpp')
  lpopt->fullname = dirbase(lpopt->sourcefile);  
  i = strlen(lpopt->fullname);
  if ( 0 == strcmp( lpopt->fullname+i-4, ".bpp" ) ) {
    lpopt->fullname[i-4] = 0;
    lpopt->sourceext = strdup(".bpp");
  } else
  if ( 0 == strcmp( lpopt->fullname+i-4, ".tgz" ) ) {
    lpopt->fullname[i-4] = 0;
    lpopt->sourceext = strdup(".tgz");
  }

  // Calcolo SoName e Version
  s = strrchr( lpopt->fullname, '_' );
  if ( s == NULL ) {
    lpopt->soname  = strdup(lpopt->fullname);
    lpopt->version = strdup("");
  } else {
    i = strlen(lpopt->fullname);
    while ( (i>0) && (lpopt->fullname[i] != '_') ) i--;
    lpopt->soname  = malloc( sizeof(char) * (i + 1) );
    strncpy( lpopt->soname, lpopt->fullname, i );
    lpopt->soname[i] = 0;
    lpopt->version = malloc( sizeof(char) * ( strlen(lpopt->fullname) - i + 1) );
    lpopt->version[0] = 0;
    strcat( lpopt->version, lpopt->fullname+i+1 );
    
  }
  
  // Calcolo directory di spool
  lpopt->spoolroot = concatenate( lpopt->targetdir, SETUP_SPOOLROOT );
  
  // Calcolo directory pacchetto
  lpopt->spooldir = concatenate( lpopt->spoolroot, lpopt->fullname );
  return 0;
}
